<?php
/**
 * Plugin Name: Holo Pay
 * Description: Accept PayPal payments with Holo Pay.
 * Version: 1.1.0
 * Requires at least: 4.9
 * Tested up to: 6.7.1
 * WC requires at least: 3.5
 * WC tested up to: 9.5.1
 * Author:  Holo Pay
 * Author URI: https://holopay.pro/
 * License: MIT
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

define('HOLOPAY_VERSION', '1.9.7');
define('HOLOPAY_PLUGIN_DIR', untrailingslashit( dirname(__FILE__)));
define('HOLOPAY_DIR_NAME', plugin_basename(dirname(__FILE__)));
define('HOLOPAY_BASE_URL', plugins_url() . '/' . HOLOPAY_DIR_NAME);
define('HOLOPAY_BASE_PATH', plugin_dir_path( __FILE__ ));


add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

register_activation_hook( __FILE__, 'activate_holo_pay');


/*
 * The code that runs during plugin activation.
*/
function activate_holo_pay() {

    // we need to display a error message before the plugin is installed.
    holopay_check_woocommerce_is_installed();
    // good to go -> activate the plugin.
}


function holopay_check_woocommerce_is_installed() {
    if (!holopay_check_woocommerce_plugin_status()) {
        // Deactivate the plugin
        deactivate_plugins(__FILE__);
        $error_message = __('The HoloPay plugin requires the <a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce</a> plugin to be active!', 'holo-pay');
        wp_die(esc_html($error_message));
    }
    return true;
}



/**
 * @return bool
 */
function holopay_check_woocommerce_plugin_status()
{
    // Test to see if WooCommerce is active (including network activated). we're good.
    if (in_array('woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option('active_plugins')))) {
        return true;
    }
    if (!is_multisite()) return false;
    $plugins = get_site_option( 'active_sitewide_plugins');
    return isset($plugins['woocommerce/woocommerce.php']);
}


// plugins loaded callback
add_action('plugins_loaded', 'holopay_on_all_plugins_loaded', 12);


/**
* Initialize the gateway.
*
* @version  1.0
*/
function holopay_on_all_plugins_loaded() {
    if (holopay_check_woocommerce_plugin_status()) {
        if (!class_exists('WC_Payment_Gateway')) {
            // oops!
            return;
        }
		require_once HOLOPAY_BASE_PATH. 'includes/regular-checkout.php';
    }
}

/**
* Return an instance of the gateway for those loader functions that need it
* so we don't keep creating it over and over again.
*
* @version  1.0
*/
add_filter( 'woocommerce_payment_gateways', 'holopay_add_gateway_class' );
function holopay_add_gateway_class( $methods ) {
    if (!in_array('WC_Gateway_HoloPay', $methods)) {
        $methods[] = 'WC_Gateway_HoloPay'; 
        return $methods;
    }
}

/**
* Register the payment method for blocks
*/
add_action( 'woocommerce_blocks_loaded', 'woocommerce_holopay_blocks_support' );
function woocommerce_holopay_blocks_support() {
    if ( class_exists( 'Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType' ) ) {
        require_once HOLOPAY_BASE_PATH. 'includes/blocks-checkout.php';
        add_action(
            'woocommerce_blocks_payment_method_type_registration',
            function( Automattic\WooCommerce\Blocks\Payments\PaymentMethodRegistry $payment_method_registry ) {
                $payment_method_registry->register( new WC_HoloPay_Blocks_Support );
            }
        );
    }
}